@@ -44,7 +44,7 @@ char *form_file_name;
 #define MAX_FORM_FILE_NAME_LEN	255
 int NEW_FILE;
 void drawForm();
-void saveForm();
+int saveForm();
 void openForm();
 void newForm();
 
