@@ -55,18 +55,18 @@ void makeProject()
   {
     fprintf(file, "/*main.c: Source file containing main() function\n");
     fprintf(file, " *        accompanying %s.\n *\n", form_file_name);
-    fprintf(file, " *Created by GNU/Linux Fog Version 1.0\n");
+    fprintf(file, " *Created by GNU/Linux Fog Version 1.1\n");
     fprintf(file, " *By Mohammed Isam, 2014\n");
     fprintf(file, 
-      " *\n *Will need to be linked against libcutils in order to compile\n");
+      " *\n *Will need to be linked against libgnudos in order to compile\n");
     fprintf(file, 
-      " *e.g.\n *  gcc -o myprog main.c form_design.c -lcutils\n */\n\n");
+      " *e.g.\n *  gcc -o myprog main.c form_design.c -lgnudos\n */\n\n");
     fprintf(file, "#include \"fog_header.h\"\n\n");
-    fprintf(file, "void sighandler(int signo) {\n");
-    fprintf(file, "\t\n");
+    fprintf(file, "void sighandler(int signo)\n");
+    fprintf(file, "{\n\t\n");
     fprintf(file, "}\n\n");
-    fprintf(file, "int main() {\n");
-    fprintf(file, "\tinit_form();\n");
+    fprintf(file, "int main()\n");
+    fprintf(file, "{\n\tinit_form();\n");
     fprintf(file, "\trefresh_form();\n");
     fprintf(file, "\tinput_loop();\n");
     fprintf(file, "\tclose_form();\n");
@@ -75,8 +75,10 @@ void makeProject()
     for(i = 0; i < total_form_tools; i++) 
     {
       if(strcmp(form_tool[i], "Button") != 0) continue;
-      fprintf(file, "\nvoid buttonClicked(int button) {\n");
-      fprintf(file, "\tswitch(button) {\n");
+      fprintf(file, "\nvoid buttonClicked(int button)\n");
+      fprintf(file, " {\n");
+      fprintf(file, "\tswitch(button)\n");
+      fprintf(file, "\t{\n");
       for(i = 0; i < total_form_tools; i++) 
       {
 	if(strcmp(form_tool[i], "Button") != 0) continue;
@@ -113,7 +115,7 @@ write_header_file:
 	    "/*fog_header.h: Header file containing function prototypes\n");
     fprintf(file, " *              and declarations accompanying %s.\n *\n",
 	    form_file_name);
-    fprintf(file, " *Created by GNU/Linux Fog Version 1.0\n");
+    fprintf(file, " *Created by GNU/Linux Fog Version 1.1\n");
     fprintf(file, " *By Mohammed Isam, 2014\n */\n\n");
     fprintf(file, "#ifndef __FOG_HEADER_H\n");
     fprintf(file, "#define __FOG_HEADER_H\n\n");
@@ -130,7 +132,8 @@ write_header_file:
     fprintf(file, "int x, y;\n");
     fprintf(file, "char *FORM_TITLE;\n");
     //fprintf(file, "int TOOLS;\n\n");
-    fprintf(file, "typedef struct {\n");
+    fprintf(file, "typedef struct\n");
+    fprintf(file, "{\n");
     fprintf(file, "  int x;\n");
     fprintf(file, "  int y;\n");
     fprintf(file, "} tpos;\n");
@@ -183,7 +186,7 @@ write_design_file:
 	    "/*form_design.c: Source file containing function definitions\n");
     fprintf(file, " *               and form design accompanying %s.\n *\n",
 	    form_file_name);
-    fprintf(file, " *Created by GNU/Linux Fog Version 1.0\n");
+    fprintf(file, " *Created by GNU/Linux Fog Version 1.1\n");
     fprintf(file, " *By Mohammed Isam, 2014\n */\n\n");
     fprintf(file, "#include \"fog_header.h\"\n");
     fprintf(file, "\n");
@@ -234,13 +237,15 @@ write_design_file:
     fprintf(file, "\tif(FORM_WIDTH > SCREEN_W) FORM_WIDTH = SCREEN_W;\n");
     fprintf(file, "\tif(FORM_HEIGHT > SCREEN_H) FORM_HEIGHT = SCREEN_H;\n");
     fprintf(file, "\tx = 1; y = 1;\n");
-    fprintf(file, "\tif(FORM_WIDTH < SCREEN_W) {\n");
+    fprintf(file, "\tif(FORM_WIDTH < SCREEN_W)\n");
+    fprintf(file, "\t{\n");
     fprintf(file, "\t\ty = (SCREEN_W-FORM_WIDTH)/2;\n");
     fprintf(file, "\t\tint i;\n");
     fprintf(file, "\t\tfor(i = 0; i < total_form_tools; i++)\n");
     fprintf(file, "\t\t  tool_pos[i].y += y;\n");
     fprintf(file, "\t}\n");
-    fprintf(file, "\tif(FORM_HEIGHT < SCREEN_H) {\n");
+    fprintf(file, "\tif(FORM_HEIGHT < SCREEN_H)\n");
+    fprintf(file, "\t{\n");
     fprintf(file, "\t\tx = (SCREEN_H-FORM_HEIGHT)/2;\n");
     fprintf(file, "\t\tint i;\n");
     fprintf(file, "\t\tfor(i = 0; i < total_form_tools; i++)\n");
@@ -249,92 +254,102 @@ write_design_file:
     fprintf(file, "\tclearScreen();\n");
     fprintf(file, "}\n");
     fprintf(file, "\n");
-    fprintf(file, "void refresh_form() {\n");
+    fprintf(file, "void refresh_form()\n");
+    fprintf(file, "{\n");
     fprintf(file, 
 	  "\tdrawBox(x, y, x+FORM_HEIGHT, y+FORM_WIDTH, FORM_TITLE, YES);\n");
     fprintf(file, "\tint i;\n");
-    fprintf(file, "\tfor(i = 0; i < total_form_tools; i++) {\n");
+    fprintf(file, "\tfor(i = 0; i < total_form_tools; i++)\n");
+    fprintf(file, "\t{\n");
     fprintf(file, "\t\tif(i == selected_tool)\n");
     fprintf(file, "\t\t\tif(strcmp(form_tool[i], \"Button\") == 0)\n");
-    fprintf(file, "\t\t\t  setScreenColors(FG_COLOR[COLOR_HBUTTONS], \
-BG_COLOR[COLOR_HBUTTONS]);\n");
+    fprintf(file, "\t\t\t  setScreenColors(FG_COLOR[COLOR_HBUTTONS], "
+				"BG_COLOR[COLOR_HBUTTONS]);\n");
     fprintf(file, "\t\t\telse\n");
-    fprintf(file, "\t\t\t  setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], \
-BG_COLOR[COLOR_HIGHLIGHT_TEXT]);\n");
+    fprintf(file, "\t\t\t  setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], "
+				"BG_COLOR[COLOR_HIGHLIGHT_TEXT]);\n");
     fprintf(file, "\t\telse\n");
     fprintf(file, "\t\t\tif(strcmp(form_tool[i], \"Button\") == 0)\n");
-    fprintf(file, "\t\t\t  setScreenColors(FG_COLOR[COLOR_BUTTONS], \
-BG_COLOR[COLOR_BUTTONS]);\n");
+    fprintf(file, "\t\t\t  setScreenColors(FG_COLOR[COLOR_BUTTONS], "
+				"BG_COLOR[COLOR_BUTTONS]);\n");
     fprintf(file, "\t\t\telse\n");
-    fprintf(file, "\t\t\t  setScreenColors(FG_COLOR[COLOR_WINDOW], \
-BG_COLOR[COLOR_WINDOW]);\n");
+    fprintf(file, "\t\t\t  setScreenColors(FG_COLOR[COLOR_WINDOW], "
+				"BG_COLOR[COLOR_WINDOW]);\n");
     fprintf(file, "\t\tlocate(tool_pos[i].x, tool_pos[i].y);\n");
     fprintf(file, "\t\t//input fields are highlighted anyway//\n");
-    fprintf(file, "\t\tif(strcmp(form_tool[i], \"Input field\") == 0) {\n");
-    fprintf(file, "\t\t\t  setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], \
-BG_COLOR[COLOR_HIGHLIGHT_TEXT]);\n");
+    fprintf(file, "\t\tif(strcmp(form_tool[i], \"Input field\") == 0)\n");
+    fprintf(file, "\t\t{\n");
+    fprintf(file, "\t\t\t  setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], "
+				"BG_COLOR[COLOR_HIGHLIGHT_TEXT]);\n");
     fprintf(file, "\t\t\t  printf(\"%%s\", input[selected_tool]);\n");
-    fprintf(file, "\t\t\t  printf(\"%%*s\", \
-FORM_WIDTH-tool_pos[selected_tool].x-strlen(input[selected_tool]), \" \");\n");
-    fprintf(file, "\t\t\t  locate(tool_pos[selected_tool].x+selectedChar, \
-tool_pos[selected_tool].y);\n");
+    fprintf(file, "\t\t\t  printf(\"%%*s\", "
+			"FORM_WIDTH-tool_pos[selected_tool]."
+			"x-strlen(input[selected_tool]), \" \");\n");
+    fprintf(file, "\t\t\t  locate(tool_pos[selected_tool].x+selectedChar, "
+			"tool_pos[selected_tool].y);\n");
     fprintf(file, "\t\t} else {\n");
     fprintf(file, "\t\t  printf(\"%%s\", form_tool_text[i]);\n");
-    fprintf(file, "\t\t  if(i == selected_option) {\n");
+    fprintf(file, "\t\t  if(i == selected_option)\n");
+    fprintf(file, "\t\t  {\n");
     fprintf(file, "\t\t    locate(tool_pos[i].x, tool_pos[i].y+1);\n");
     fprintf(file, "\t\t    printf(\"X\");\n");
     fprintf(file, "\t\t  }\n");
-    fprintf(file, "\t\t  locate(tool_pos[selected_tool].x, \
-tool_pos[selected_tool].y);\n");
+    fprintf(file, "\t\t  locate(tool_pos[selected_tool].x, "
+			"tool_pos[selected_tool].y);\n");
     fprintf(file, "\t\t}\n");
     fprintf(file, "\t}\n");
     fprintf(file, "\tfflush(stdout);\n");
     fprintf(file, "}\n");
     fprintf(file, "\n");
-    fprintf(file, "void input_loop() {\n");
+    fprintf(file, "void input_loop()\n");
+    fprintf(file, "{\n");
     fprintf(file, "\tint c;\n");
     fprintf(file, "\tint i;\n");
     fprintf(file, "\tstatic int selectedChar = 0;\n");
-    fprintf(file, "\twhile(1) {\n");
+    fprintf(file, "\twhile(1)\n");
+    fprintf(file, "\t{\n");
     fprintf(file, "\t\tc = getKey();\n");
-    fprintf(file, "\t\tswitch(c) {\n");
+    fprintf(file, "\t\tswitch(c)\n");
+    fprintf(file, "\t\t{\n");
     fprintf(file, "\t\tcase(LEFT_KEY):\n");
-    fprintf(file, "\t\t  if(strcmp(form_tool[selected_tool], \
-\"Input field\") == 0) {\n");
+    fprintf(file, "\t\t  if(strcmp(form_tool[selected_tool], "
+			"\"Input field\") == 0)\n");
+    fprintf(file, "\t\t  {\n");
     fprintf(file, "\t\t    if(selectedChar > 0) selectedChar--;\n");
-    fprintf(file, "\t\t    locate(tool_pos[selected_tool].x+selectedChar, \
-tool_pos[selected_tool].y);\n");
+    fprintf(file, "\t\t    locate(tool_pos[selected_tool].x+selectedChar, "
+			"tool_pos[selected_tool].y);\n");
     fprintf(file, "\t\t    break;\n");
     fprintf(file, "\t\t  }\n");
     fprintf(file, "\t\tcase(UP_KEY):\n");
     fprintf(file, "\t\t  selected_tool--;\n");
-    fprintf(file, "\t\t  if(selected_tool < 0) selected_tool = \
-total_form_tools-1;\n");
-    fprintf(file, "\t\t  while(strcmp(form_tool[selected_tool], \
-\"Message field\") == 0)\n");
-    fprintf(file, "\t\t    { selected_tool--; if(selected_tool == 0) \
-break; }\n");
+    fprintf(file, "\t\t  if(selected_tool < 0) selected_tool = "
+			"total_form_tools-1;\n");
+    fprintf(file, "\t\t  while(strcmp(form_tool[selected_tool], "
+			"\"Message field\") == 0)\n");
+    fprintf(file, "\t\t    { selected_tool--; if(selected_tool == 0) "
+			"break; }\n");
     fprintf(file, "\t\t  selectedChar = 0;\n");
     fprintf(file, "\t\t  refresh_form();\n");
     fprintf(file, "\t\t  break;\n");
     fprintf(file, "\t\tcase(RIGHT_KEY):\n");
-    fprintf(file, "\t\t  if(strcmp(form_tool[selected_tool], \
-\"Input field\") == 0) {\n");
-    fprintf(file, "\t\t    if(selectedChar < strlen(input[selected_tool]) \
-selectedChar++;\n");
-    fprintf(file, "\t\t    locate(tool_pos[selected_tool].x+selectedChar, \
-tool_pos[selected_tool].y);\n");
+    fprintf(file, "\t\t  if(strcmp(form_tool[selected_tool], "
+			"\"Input field\") == 0)\n");
+    fprintf(file, "\t\t  {\n");
+    fprintf(file, "\t\t    if(selectedChar < strlen(input[selected_tool]) "
+			"selectedChar++;\n");
+    fprintf(file, "\t\t    locate(tool_pos[selected_tool].x+selectedChar, "
+			"tool_pos[selected_tool].y);\n");
     fprintf(file, "\t\t    break;\n");
     fprintf(file, "\t\t  }\n");
     fprintf(file, "\t\tcase(TAB_KEY):\n");
     fprintf(file, "\t\tcase(DOWN_KEY):\n");
     fprintf(file, "\t\t  selected_tool++;\n");
-    fprintf(file, "\t\t  if(selected_tool > total_form_tools-1) \
-selected_tool = 0;\n");
-    fprintf(file, "\t\t  while(strcmp(form_tool[selected_tool], \
-\"Message field\") == 0)\n");
-    fprintf(file, "\t\t    { selected_tool++; if(selected_tool \
->= total_form_tools-1) break; }\n");
+    fprintf(file, "\t\t  if(selected_tool > total_form_tools-1) "
+			"selected_tool = 0;\n");
+    fprintf(file, "\t\t  while(strcmp(form_tool[selected_tool], "
+			"\"Message field\") == 0)\n");
+    fprintf(file, "\t\t    { selected_tool++; if(selected_tool "
+			">= total_form_tools-1) break; }\n");
     fprintf(file, "\t\t  selectedChar = 0;\n");
     fprintf(file, "\t\t  refresh_form();\n");
     fprintf(file, "\t\t  break;\n");
@@ -342,100 +357,107 @@ selected_tool = 0;\n");
     fprintf(file, "\t\t  return; break;\n");
     //fprintf(file, "\t\tcase(SPACE_KEY):\n");
     fprintf(file, "\t\tcase(ENTER_KEY):\n");
-    fprintf(file, "\t\t  if(strcmp(form_tool[selected_tool], \
-\"Button\") == 0)\n");
+    fprintf(file, "\t\t  if(strcmp(form_tool[selected_tool], "
+			"\"Button\") == 0)\n");
     fprintf(file, "\t\t  { buttonClicked(selected_tool); break; }\n");
-    fprintf(file, "\t\t  if(strcmp(form_tool[selected_tool], \
-\"Option item\") == 0)\n");
+    fprintf(file, "\t\t  if(strcmp(form_tool[selected_tool], "
+			"\"Option item\") == 0)\n");
     fprintf(file, "\t\t    if(selected_tool != selected_option) {\n");
-    fprintf(file, "\t\t      setScreenColors(FG_COLOR[COLOR_WINDOW], \
-BG_COLOR[COLOR_WINDOW]);\n");
-    fprintf(file, "\t\t      locate(tool_pos[selected_option].x, \
-tool_pos[selected_option].y);\n");
-    fprintf(file, "\t\t      printf(\"%%s\", \
-form_tool_text[selected_option]);\n");
+    fprintf(file, "\t\t      setScreenColors(FG_COLOR[COLOR_WINDOW], "
+			"BG_COLOR[COLOR_WINDOW]);\n");
+    fprintf(file, "\t\t      locate(tool_pos[selected_option].x, "
+			"tool_pos[selected_option].y);\n");
+    fprintf(file, "\t\t      printf(\"%%s\", "
+			"form_tool_text[selected_option]);\n");
     fprintf(file, "\t\t      selected_option = selected_tool;\n");
-    fprintf(file, "\t\t      setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], \
-BG_COLOR[COLOR_HIGHLIGHT_TEXT]);\n");
-    fprintf(file, "\t\t      locate(tool_pos[selected_option].x, \
-tool_pos[selected_option].y);\n");
-    fprintf(file, "\t\t      printf(\"%%s\", \
-form_tool_text[selected_option]);\n");
-    fprintf(file, "\t\t      locate(tool_pos[selected_option].x, \
-tool_pos[selected_option].y+1);\n");
+    fprintf(file, "\t\t      setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], "
+			"BG_COLOR[COLOR_HIGHLIGHT_TEXT]);\n");
+    fprintf(file, "\t\t      locate(tool_pos[selected_option].x, "
+			"tool_pos[selected_option].y);\n");
+    fprintf(file, "\t\t      printf(\"%%s\", "
+			"form_tool_text[selected_option]);\n");
+    fprintf(file, "\t\t      locate(tool_pos[selected_option].x, "
+			"tool_pos[selected_option].y+1);\n");
     fprintf(file, "\t\t      printf(\"X\");\n");
     fprintf(file, "\t\t      fflush(stdout);\n");
     fprintf(file, "\t\t    }\n");
     fprintf(file, "\t\t  break;\n");
     fprintf(file, "\t\tcase(DEL_KEY):\n");
-    fprintf(file, "\t\t  if(strcmp(form_tool[selected_tool], \
-\"Input field\") == 0) {\n");
-    fprintf(file, "\t\t    if(selectedChar == strlen(input[selected_tool]) \
-break;\n");
-    fprintf(file, "\t\t    for(i = selectedChar; i \
-< strlen(input[selected_tool]); i++) input[selected_tool][i] \
-= input[selected_tool][i+1];\n");
-    fprintf(file, "\t\t    locate(tool_pos[selected_tool].x, \
-tool_pos[selected_tool].y);\n");
-    fprintf(file, "\t\t    setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], \
-BG_COLOR[COLOR_HIGHLIGHT_TEXT]);\n");
+    fprintf(file, "\t\t  if(strcmp(form_tool[selected_tool], "
+			"\"Input field\") == 0)\n");
+    fprintf(file, "\t\t  {\n");
+    fprintf(file, "\t\t    if(selectedChar == strlen(input[selected_tool]) "
+			"break;\n");
+    fprintf(file, "\t\t    for(i = selectedChar; i "
+		"< strlen(input[selected_tool]); i++) input[selected_tool][i] "
+		"= input[selected_tool][i+1];\n");
+    fprintf(file, "\t\t    locate(tool_pos[selected_tool].x, "
+		"tool_pos[selected_tool].y);\n");
+    fprintf(file, "\t\t    setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], "
+		"BG_COLOR[COLOR_HIGHLIGHT_TEXT]);\n");
     fprintf(file, "\t\t    printf(\"%%s\", input[selected_tool]);\n");
-    fprintf(file, "\t\t    printf(\"%%*s\", \
-FORM_WIDTH-tool_pos[selected_tool].x-strlen(input[selected_tool]), \" \");\n");
-    fprintf(file, "\t\t    locate(tool_pos[selected_tool].x+selectedChar, \
-tool_pos[selected_tool].y);\n");
+    fprintf(file, "\t\t    printf(\"%%*s\", "
+		"FORM_WIDTH-tool_pos[selected_tool]."
+		"x-strlen(input[selected_tool]), \" \");\n");
+    fprintf(file, "\t\t    locate(tool_pos[selected_tool].x+selectedChar, "
+		"tool_pos[selected_tool].y);\n");
     fprintf(file, "\t\t    break;\n");
     fprintf(file, "\t\t  }\n");
     fprintf(file, "\t\tcase(BACKSPACE_KEY):\n");
-    fprintf(file, "\t\t  if(strcmp(form_tool[selected_tool], \"Input field\") \
-== 0) {\n");
+    fprintf(file, "\t\t  if(strcmp(form_tool[selected_tool], \"Input field\") "
+		"== 0)\n\t\t  {\n");
     fprintf(file, "\t\t    if(selectedChar == 0) break;\n");
     fprintf(file, "\t\t    selectedChar--;\n");
-    fprintf(file, "\t\t    for(i = selectedChar; i \
-< strlen(input[selected_tool]); i++) input[selected_tool][i] \
-= input[selected_tool][i+1];\n");
-    fprintf(file, "\t\t    locate(tool_pos[selected_tool].x, \
-tool_pos[selected_tool].y);\n");
-    fprintf(file, "\t\t    setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], \
-BG_COLOR[COLOR_HIGHLIGHT_TEXT]);\n");
+    fprintf(file, "\t\t    for(i = selectedChar; i "
+		"< strlen(input[selected_tool]); i++) input[selected_tool][i] "
+		"= input[selected_tool][i+1];\n");
+    fprintf(file, "\t\t    locate(tool_pos[selected_tool].x, "
+		"tool_pos[selected_tool].y);\n");
+    fprintf(file, "\t\t    setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], "
+		"BG_COLOR[COLOR_HIGHLIGHT_TEXT]);\n");
     fprintf(file, "\t\t    printf(\"%%s\", input[selected_tool]);\n");
-    fprintf(file, "\t\t    printf(\"%%*s\", \
-FORM_WIDTH-tool_pos[selected_tool].x-strlen(input[selected_tool]), \" \");\n");
-    fprintf(file, "\t\t    locate(tool_pos[selected_tool].x+selectedChar, \
-tool_pos[selected_tool].y);\n");
+    fprintf(file, "\t\t    printf(\"%%*s\", "
+		"FORM_WIDTH-tool_pos[selected_tool]."
+		"x-strlen(input[selected_tool]), \" \");\n");
+    fprintf(file, "\t\t    locate(tool_pos[selected_tool].x+selectedChar, "
+		"tool_pos[selected_tool].y);\n");
     fprintf(file, "\t\t    break;\n");
     fprintf(file, "\t\t  }\n");
     fprintf(file, "\t\tdefault:\n");
-    fprintf(file, "\t\t  if(strcmp(form_tool[selected_tool], \"Input field\") \
-== 0)\n");
-    fprintf(file, "\t\t    if(c >= 32 && c <= 126) {\n");
-    fprintf(file, "\t\t      if(strlen(input[selected_tool]) \
->= FORM_WIDTH-tool_pos[selected_tool].x-2) break;\n");
-    fprintf(file, "\t\t      if(selectedChar == strlen(input[selected_tool])) \
-{\n");
+    fprintf(file, "\t\t  if(strcmp(form_tool[selected_tool], \"Input field\") "
+		"== 0)\n");
+    fprintf(file, "\t\t    if(c >= 32 && c <= 126)\n");
+    fprintf(file, "\t\t    {\n");
+    fprintf(file, "\t\t      if(strlen(input[selected_tool]) "
+		">= FORM_WIDTH-tool_pos[selected_tool].x-2) break;\n");
+    fprintf(file, "\t\t      if(selectedChar == strlen(input[selected_tool])) "
+		"\n\t\t      {\n");
     fprintf(file, "\t\t        input[selected_tool][selectedChar] = c;\n");
-    fprintf(file, "\t\t        input[selected_tool][selectedChar+1] = '\\0'\
-;\n");
+    fprintf(file, "\t\t        input[selected_tool][selectedChar+1] = '\\0'"
+		";\n");
     fprintf(file, "\t\t        putchar(c);\n");
     fprintf(file, "\t\t        selectedChar++;\n");
-    fprintf(file, "\t\t      } else {\n");
+    fprintf(file, "\t\t      }\n");
+    fprintf(file, "\t\t      else\n");
+    fprintf(file, "\t\t      {\n");
     fprintf(file, "\t\t        char *tmp = (char *) malloc(MAX_INPUT_LEN);\n");
-    fprintf(file, "\t\t        strcpy(tmp, input[selected_tool]+selectedChar);\
-\n");
+    fprintf(file, "\t\t        strcpy(tmp, input[selected_tool]+selectedChar);"
+		"\n");
     fprintf(file, "\t\t        input[selected_tool][selectedChar] = c;\n");
-    fprintf(file, "\t\t        input[selected_tool][selectedChar+1] = '\\0';\
-\n");
+    fprintf(file, "\t\t        input[selected_tool][selectedChar+1] = '\\0';"
+		"\n");
     fprintf(file, "\t\t        strcat(input[selected_tool], tmp);\n");
     fprintf(file, "\t\t        selectedChar++;\n");
-    fprintf(file, "\t\t        locate(tool_pos[selected_tool].x, \
-tool_pos[selected_tool].y);\n");
-    fprintf(file, "\t\t        setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT],\
- BG_COLOR[COLOR_HIGHLIGHT_TEXT]);\n");
+    fprintf(file, "\t\t        locate(tool_pos[selected_tool].x, "
+		"tool_pos[selected_tool].y);\n");
+    fprintf(file, "\t\t        setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT],"
+		" BG_COLOR[COLOR_HIGHLIGHT_TEXT]);\n");
     fprintf(file, "\t\t        printf(\"%%s\", input[selected_tool]);\n");
-    fprintf(file, "\t\t        printf(\"%%*s\", \
-FORM_WIDTH-tool_pos[selected_tool].x-strlen(input[selected_tool]), \" \");\n");
-    fprintf(file, "\t\t        locate(tool_pos[selected_tool].x+selectedChar, \
-tool_pos[selected_tool].y);\n");
+    fprintf(file, "\t\t        printf(\"%%*s\", "
+		"FORM_WIDTH-tool_pos[selected_tool]."
+		"x-strlen(input[selected_tool]), \" \");\n");
+    fprintf(file, "\t\t        locate(tool_pos[selected_tool].x+selectedChar, "
+		"tool_pos[selected_tool].y);\n");
     fprintf(file, "\t\t        free(tmp);\n");
     fprintf(file, "\t\t      }\n");
     fprintf(file, "\t\t    }\n");
@@ -444,7 +466,7 @@ tool_pos[selected_tool].y);\n");
     fprintf(file, "\t}//end while\n");
     fprintf(file, "}\n");
     fprintf(file, "\n");
-    fprintf(file, "void close_form() {\n");
+    fprintf(file, "void close_form()\n{\n");
     fprintf(file, "\trestoreTerminal();\n");
     fprintf(file, "\tsetScreenColors(WHITE, BGBLACK);\n");
     fprintf(file, "\tclearScreen();\n");
@@ -471,4 +493,4 @@ finished:
   drawToolBox();
   drawStatusBar();
   return;
-}
\ No newline at end of file
+}
