@@ -32,19 +32,20 @@ void showQuickReference()
 {
 	    drawBox(3, 5, 18, SCREEN_W-5, "Quick Reference", YES);
 	    fprintf(stdout, "\e[4;7HBasic functions:");
-	    fprintf(stdout, "\e[5;9HSPACEBAR: Toggle select/unselect");
-	    fprintf(stdout, "\e[6;9HENTER: Navigate to directory");
-	fprintf(stdout, "\e[7;9HTAB: Navigate between dir/file view windows");
-	    fprintf(stdout, "\e[8;9HArrow keys: Navigate up/down");
-	    fprintf(stdout, "\e[10;7HEditing:");
-	    fprintf(stdout, "\e[11;9HDEL: Delete marked directories/files");
-	    fprintf(stdout, "\e[12;9HCTRL+X: Cut marked directories/files");
-	    fprintf(stdout, "\e[13;9HCTRL+C: Copy marked directories/files");
-	    fprintf(stdout, "\e[14;9HCTRL+V: Paste marked directories/files");
-	    fprintf(stdout, "\e[15;9HCTRL+F: Find files");
+	    fprintf(stdout, "\e[5;9HT    : Activate the toolbox");
+	    fprintf(stdout, "\e[6;9HF    : Activate the form");
+	    fprintf(stdout, "\e[7;9HENTER: Add a tool (if Toolbox active)");
+	    fprintf(stdout, "\e[8;9H       Edit tool text (if Form active)");
+	    fprintf(stdout, "\e[10;7DELETE: Remove tool");
+	    fprintf(stdout, "\e[11;9HMenus:");
+	    fprintf(stdout, "\e[12;9HALT+F: Open file menu");
+	    fprintf(stdout, "\e[13;9HALT+E: Open edit menu");
+	    fprintf(stdout, "\e[14;9HALT+O: Open options menu");
+	    fprintf(stdout, "\e[15;9HALT+H: Open help menu");
 	    fprintf(stdout, "\e[16;9HCTRL+Q: Quit the program");
 	    fprintf(stdout, "\e[17;7HPress any key to continue..");
-	    do {;} while(!getKey());
+	    //char c = getKey();
+	    do {;} while(getKey() < 0);
 }
 
 /******************************************
