@@ -117,7 +117,7 @@ void init();
 void init_built_in_defaults();
 void init_error();
 void exit_gracefully(int exit_code);
-void parseLineArgs(int argc, char *argv[]);
+void parseLineArgs(int argc, char **argv);
 int scanDir(char *dir);
 
 int msgBox(char *msg, int Buttons, msgType tmsg);
@@ -151,11 +151,11 @@ char *menu[4];
 #define totalMainMenus	4	//total items in main menu bar
 #define fTotal		6	//total items in file menu
 #define eTotal		10	//total items in mino menu
-#define oTotal		3	//total items in options menu
+#define oTotal		4	//total items in options menu
 #define hTotal		4	//total items in help menu
 char *fileMenu[6];
 char *editMenu[10];
-char *optionsMenu[3];
+char *optionsMenu[4];
 char *helpMenu[4];
 
 int x, y, w, h;
