@@ -138,7 +138,12 @@ char* inputBox(char *msg, char *title)
     ch = getKey();
     switch(ch[0]) 
     {
+      case('g'):
+	if(GNU_DOS_LEVEL > 2 && CTRL) goto do_esc;
+	goto enterInputChar;
       case(ESC_KEY):
+	if(GNU_DOS_LEVEL > 2) break;
+do_esc:
 	firstVisChar = 0; highlightChar = 0; inputLen = 0;
 	return NULL;
 	break;
@@ -151,8 +156,9 @@ char* inputBox(char *msg, char *title)
       case(ENTER_KEY):
 	if(sel == 0 || sel == 2) 
 	{	//pressed ENTER on OK button or on the input field
-	  firstVisChar = 0; highlightChar = 0; inputLen = 0;
+	  firstVisChar = 0; highlightChar = 0;
 	  if(inputLen <= 0) return NULL;	//if no input entered, return NULL
+	  inputLen = 0;
 	  return input;				//otherwise return the input
 	}
 	if(sel == 1) 
@@ -161,7 +167,12 @@ char* inputBox(char *msg, char *title)
 	  return NULL;		//return NULL also if selected CANCEL
 	}
 	break;
+      case('f'):
+	if(GNU_DOS_LEVEL > 1 && CTRL) goto do_right;
+	goto enterInputChar;
       case(RIGHT_KEY):
+	if(GNU_DOS_LEVEL > 1) break;
+do_right:
 	if(highlightChar >= inputLen) break;	//already at last char
 	//if(inputLen > msgW-3) { 
 	//}
@@ -177,7 +188,12 @@ char* inputBox(char *msg, char *title)
 	      highlightChar++;
 	      fprintf(stdout, "\x1b[%d;%dH", bx-2, y+highlightChar);	//adjust cursor to point at input field
 	} fflush(stdout); break;
+      case('b'):
+	if(GNU_DOS_LEVEL > 1 && CTRL) goto do_left;
+	goto enterInputChar;
       case(LEFT_KEY):
+	if(GNU_DOS_LEVEL > 1) break;
+do_left:
       	if(firstVisChar == 0 && highlightChar == 0) break;	//already at first char
 	if(highlightChar == 0 && firstVisChar != 0) 
 	{	//need to scroll string
@@ -234,7 +250,12 @@ char* inputBox(char *msg, char *title)
 	    fprintf(stdout, "\x1b[%d;%dH", bx, by-9);	//adjust cursor to point at "OK"
 	  }
 	fflush(stdout); break;
+      case('d'):
+	if(GNU_DOS_LEVEL > 3 && CTRL) goto do_del;
+	goto enterInputChar;
       case(DEL_KEY):
+	if(GNU_DOS_LEVEL > 3) break;
+do_del:
 	if((firstVisChar+highlightChar) == (inputLen))
 	  break;	//can't delete.. at the last char
 	for(i = firstVisChar+highlightChar; i < inputLen-1; i++) 
@@ -483,7 +504,12 @@ int msgBox(char *msg, int Buttons, msgType tmsg)
     ch = getKey();
     switch(ch[0]) 
     {
+      case('g'):
+	if(GNU_DOS_LEVEL > 2 && CTRL) goto do_esc;
+	break;
       case(ESC_KEY):
+	if(GNU_DOS_LEVEL > 2) break;
+do_esc:
 	return CANCEL; break;
       case(SPACE_KEY):
       case(ENTER_KEY): 	//remember, Buttons = 5 for OK/CANEL, and = 10 for YES/NO
@@ -493,9 +519,15 @@ int msgBox(char *msg, int Buttons, msgType tmsg)
 	if(sel == 1 && Buttons == 10) return NO;
 	if(sel == 0 && Buttons == 1) return OK;
 	break;
+      case('b'):
+      case('f'):
+	if(GNU_DOS_LEVEL > 1 && CTRL) goto do_tab;
+	break;
       case(RIGHT_KEY):
       case(LEFT_KEY):
+	if(GNU_DOS_LEVEL > 1) break;
       case(TAB_KEY):
+do_tab:
 	  bx = x + (msgH-3);
 	  by = y + ((msgW-16)/2) - 2;
 	  if(sel == 0 && Buttons == 5) 
